@@ -36,8 +36,8 @@ private:
 
   double sampleRate;
 
-  float dry_level;
-  float wet_level;
+  float dryLevel = 0.0;
+  float wetLevel = 0.0;
 
   static const uint32_t BUFFER_SIZE = 256;
 
